@@ -61,6 +61,8 @@ import java.net.MalformedURLException;
 import java.net.URL;
 import java.net.URLEncoder;
 import java.util.List;
+import java.util.Map;
+import java.util.Map.Entry;
 import javax.management.openmbean.CompositeData;
 import javax.net.ssl.HttpsURLConnection;
 import org.json.JSONException;
@@ -87,11 +89,10 @@ public class TransportHandler {
 
     private static final String URL_ENCODING = "UTF-8";
 
-    public TransportHandler() {
-    }
+    public TransportHandler() {}
 
-    public void sendReport(final List<Total> totals, final List<MacDetail> macDetails, final List<ContextDetail> contextDetails, final String[] versions, final ClientLoginCount clc, final ClientLoginCount clcYear, final boolean savereport) throws IOException, JSONException {
-        final JSONObject metadata = buildJSONObject(totals, macDetails, contextDetails, versions, clc, clcYear);
+    public void sendReport(final List<Total> totals, final List<MacDetail> macDetails, final List<ContextDetail> contextDetails, Map<String, String> serverConfiguration, final String[] versions, final ClientLoginCount clc, final ClientLoginCount clcYear, final boolean savereport) throws IOException, JSONException {
+        final JSONObject metadata = buildJSONObject(totals, macDetails, contextDetails, serverConfiguration, versions, clc, clcYear);
 
         send(metadata, savereport);
     }
@@ -136,9 +137,7 @@ public class TransportHandler {
             if ("true".equals(reportConfiguration.getUseProxy().trim()) && "true".equals(reportConfiguration.getProxyAuthRequired().trim())) {
                 final String proxyAutorizationProperty = "Basic " + Base64.encode((reportConfiguration.getProxyUsername().trim() + ":" + reportConfiguration.getProxyPassword().trim()).getBytes());
 
-                Authenticator.setDefault(new ProxyAuthenticator(
-                    reportConfiguration.getProxyUsername().trim(),
-                    reportConfiguration.getProxyPassword().trim()));
+                Authenticator.setDefault(new ProxyAuthenticator(reportConfiguration.getProxyUsername().trim(), reportConfiguration.getProxyPassword().trim()));
 
                 httpsURLConnection.setRequestProperty("Proxy-Authorization", proxyAutorizationProperty);
             }
@@ -160,7 +159,7 @@ public class TransportHandler {
         }
     }
 
-    private JSONObject buildJSONObject(final List<Total> totals, final List<MacDetail> macDetails, final List<ContextDetail> contextDetails, final String[] versions, final ClientLoginCount clc, final ClientLoginCount clcYear) throws JSONException {
+    private JSONObject buildJSONObject(final List<Total> totals, final List<MacDetail> macDetails, final List<ContextDetail> contextDetails, Map<String, String> serverConfiguration, final String[] versions, final ClientLoginCount clc, final ClientLoginCount clcYear) throws JSONException {
         final JSONObject retval = new JSONObject();
 
         final JSONObject total = new JSONObject();
@@ -169,6 +168,7 @@ public class TransportHandler {
         final JSONObject version = new JSONObject();
         final JSONObject clientlogincount = new JSONObject();
         final JSONObject clientlogincountyear = new JSONObject();
+        final JSONObject configuration = new JSONObject();
 
         final boolean wantsdetails = (null != contextDetails);
 
@@ -181,6 +181,8 @@ public class TransportHandler {
         for (final Total tmp : totals) {
             total.put("contexts", tmp.getContexts());
             total.put("users", tmp.getUsers());
+            total.put("guests", tmp.getGuests());
+            total.put("links", tmp.getLinks());
         }
 
         for (final MacDetail tmp : macDetails) {
@@ -233,6 +235,13 @@ public class TransportHandler {
         if (wantsdetails) {
             retval.put("detail", detail);
         }
+
+        if (serverConfiguration != null) {
+            for (Entry<String, String> config : serverConfiguration.entrySet()) {
+                configuration.put(config.getKey(), config.getValue());
+            }
+            retval.put("configs", configuration);
+        }
         retval.put("version", version);
         retval.put("clientlogincount", clientlogincount);
         retval.put("clientlogincountyear", clientlogincountyear);
@@ -241,7 +250,6 @@ public class TransportHandler {
     }
 
     public void sendASReport(CompositeData report, boolean savereport) throws IOException, JSONException {
-        send(new JSONObject((String)report.get("data")), savereport);
+        send(new JSONObject((String) report.get("data")), savereport);
     }
-
 }
